Class: Boosted::Jobs::Base
- Inherits:
-
Object
- Object
- Boosted::Jobs::Base
- Defined in:
- lib/boosted/jobs/base.rb
Overview
Base class for all jobs in the application.
This class is used to provide a common interface for all jobs used by Boosted
and to allow for easy configuration of the parent class.
By default, the parent class is set to ActiveJob::Base.